==> eg_particle_interactions-v0.8-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/shatter/BlockShatter.java <==
package games.enchanted.eg_particle_interactions.common.particle.shatter;

import net.minecraft.class_2350;
import net.minecraft.class_2388;
import net.minecraft.class_2423;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class BlockShatter extends AbstractShatter {
    protected final class_2680 blockState;

    protected BlockShatter(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_2680 blockState) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed);

        this.blockState = blockState;
        this.sprite = class_310.method_1551().method_1541().method_3351().method_3339(blockState);
    }

    @Override
    protected class_2350 getParticleFacingDirection() {
        return this.blockState.method_28498(class_2423.field_11310) ? this.blockState.method_11654(class_2423.field_11310).method_64922() : null;
    }

    public static class BlockShatterProvider implements class_707<class_2388> {
        public BlockShatterProvider(class_4002 spriteSet) {}

        @Nullable
        @Override
        public class_703 createParticle(@NotNull class_2388 type, @NotNull class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed) {
            return new BlockShatter(level, x, y, z, xSpeed, ySpeed, zSpeed, type.method_10278());
        }
    }
}

==> eg_particle_interactions-v0.8.4-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/shatter/BlockShatter.java <==
package games.enchanted.eg_particle_interactions.common.particle.shatter;

import net.minecraft.class_2350;
import net.minecraft.class_2388;
import net.minecraft.class_2423;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class BlockShatter extends AbstractShatter {
    protected final class_2680 blockState;

    protected BlockShatter(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_2680 blockState) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed);

        this.blockState = blockState;
        this.sprite = class_310.method_1551().method_1541().method_3351().method_3339(blockState);
    }

    @Override
    protected class_2350 getParticleFacingDirection() {
        return this.blockState.method_28498(class_2423.field_11310) ? this.blockState.method_11654(class_2423.field_11310).method_64922() : null;
    }

    public static class BlockShatterProvider implements class_707<class_2388> {
        public BlockShatterProvider(class_4002 spriteSet) {}

        @Override
        public @Nullable class_703 createParticle(
            class_2388 type,
            class_638 level,
            double x,
            double y,
            double z,
            double xSpeed,
            double ySpeed,
            double zSpeed
            //? if minecraft: > 1.21.8 {
            /*, RandomSource random
            *///?}
        ) {
            return new BlockShatter(level, x, y, z, xSpeed, ySpeed, zSpeed, type.method_10278());
        }
    }
}
